@@ -29,6 +29,8 @@ import pyparticles.animation.animated_scatter as anim
 
 import pyparticles.animation as pan
 
+import pyparticles.animation.test_animation as test
+
 import pyparticles.pset.rand_cluster as clu
 import pyparticles.forces.gravity as gr
 import pyparticles.ode.euler_solver as els
@@ -40,6 +42,7 @@ import matplotlib.animation as animation
 
 
 
+
 import pyparticles.pset.periodic_boundary as pb
 import pyparticles.pset.rebound_boundary as rb
 import pyparticles.forces.const_force as cf
@@ -52,6 +55,7 @@ import pyparticles.demo.springs as spr
 import pyparticles.demo.gas_lennard_jones as lj
 import pyparticles.demo.bubble as bu
 import pyparticles.demo.springs_constr as spc
+import pyparticles.demo.test as tst
 
 import pyparticles.utils.parse_args as arg 
 
@@ -69,8 +73,7 @@ import time
 
 import sys
 
-if sys.version_info[0] == 2:
-    import pyparticles.animation.animated_ogl as aogl
+import pyparticles.animation.animated_ogl as aogl
 
 
 def main():
@@ -87,6 +90,13 @@ def main():
         print( py_particle_version() )
         return
     
+    if options.test :
+        print("")
+        print("Start a test simulation:")
+        print(" It compares the simulated solution with the analytical solution in a specific problem")
+        tst.test( options.test )
+        return
+    
     if options.config_model :
         file_name = "example_pyparticles_config.cfg"
         cfg.write_example_config_file("example_pyparticles_config.cfg")
@@ -184,7 +194,7 @@ class MyField( vf.VectorFieldForce ):
 
 
 def my_test() :
-    
+        
     t = tr.Transformations()
     
     t.set_points_tuple_size(1)
